@@ -1,8 +1,8 @@
-from . import routes
+from . import routes  # noqa: F401
 
 
 def version():
     # with open("pyproject.toml") as f:
     #     ret = re.findall(r'version = "(\d+\.\d+\.\d+)"', f.read())
     #     return ret[0]
-    return "0.2.8"
+    return "0.2.9"
