@@ -3,9 +3,13 @@ from tortoise import Model, fields
 from fastapi_admin import enums
 
 
-class User(Model):
+class AbstractUser(Model):
     username = fields.CharField(max_length=20, unique=True)
-    password = fields.CharField(max_length=200, description="Will auto hash with raw password")
+    password = fields.CharField(
+        max_length=200, description="Will auto hash with raw password when change"
+    )
+    is_active = fields.BooleanField(default=True,)
+    is_superuser = fields.BooleanField(default=False)
 
     class Meta:
         abstract = True
