@@ -5,8 +5,8 @@ from pydantic import BaseModel
 
 
 class LoginIn(BaseModel):
-    username: str = Body(..., example='long2ice')
-    password: str = Body(..., example='123456')
+    username: str = Body(..., example="long2ice")
+    password: str = Body(..., example="123456")
 
 
 class BulkIn(BaseModel):
